@@ -12,28 +12,36 @@
 
 #include <QGraphicsScene>
 #include <QGraphicsView>
+#include <QGraphicsLinearLayout>
 
-TrailGPXView::TrailGPXView(QWidget *parent) :
+#include "trailinterface.h"
+
+TrailGPXView::TrailGPXView(TrailInterface *interface, QWidget *parent) :
     QWidget(parent)
 {
     m_layout = new QVBoxLayout();
 
     m_scene = new QGraphicsScene(this);
     m_qgv = new QGraphicsView(m_scene, this);
+
     m_qgv->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_qgv->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_qgv->setVisible(true);
     m_qgv->setInteractive(true);
 
-    serviceProvider = new QtMobility::QGeoServiceProvider("nokia");
-    manager = serviceProvider->mappingManager();
+    m_mapWidget = new MapWidget(interface->mappingManager());
+    m_mapWidget->setCenter(QtMobility::QGeoCoordinate(-27.0, 152.0));
+    m_mapWidget->setZoomLevel(5);
+    m_mapWidget->setMapType(QtMobility::QGraphicsGeoMap::TerrainMap);
 
-    m_mapView = new MapWidget(manager);
-    m_mapView->setCenter(QtMobility::QGeoCoordinate(-27.0, 152.0));
-    m_mapView->setZoomLevel(5);
-    m_mapView->setMapType(QtMobility::QGraphicsGeoMap::TerrainMap);
+    QGraphicsLinearLayout *layout = new QGraphicsLinearLayout;
+    layout->addItem(m_mapWidget);
 
-    m_scene->addItem(m_mapView);
+    QGraphicsWidget *form = new QGraphicsWidget;
+    form->setLayout(layout);
+    m_scene->addItem(form);
+
+    //m_scene->addItem(m_mapWidget);
 
     m_layout->addWidget(m_qgv);
     setLayout(m_layout);
@@ -41,14 +49,14 @@ TrailGPXView::TrailGPXView(QWidget *parent) :
 
 void TrailGPXView::addMapObject(QtMobility::QGeoMapObject *obj, bool fit)
 {
-    m_mapView->addMapObject(obj);
+    m_mapWidget->addMapObject(obj);
 
     if (fit) {
-        m_mapView->fitInViewport(obj->boundingBox());
+        m_mapWidget->fitInViewport(obj->boundingBox());
     }
 }
 
 void TrailGPXView::clearMapObjects()
 {
-    m_mapView->clearMapObjects();
+    m_mapWidget->clearMapObjects();
 }
