@@ -4,19 +4,19 @@
 #include <QWidget>
 #include <QtLocation/QGeoMapObject>
 #include <QtLocation/QGraphicsGeoMap>
-#include <QtLocation/QGeoServiceProvider>
-#include <QtLocation/QGeoMappingManager>
+
 #include <QGraphicsScene>
 #include <QGraphicsView>
 
 class QWebView;
 class QVBoxLayout;
+class TrailInterface;
 
 class TrailGPXView : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TrailGPXView(QWidget *parent = 0);
+    explicit TrailGPXView(TrailInterface*, QWidget *parent = 0);
 
     void addMapObject(QtMobility::QGeoMapObject*, bool fit);
     void clearMapObjects();
@@ -26,10 +26,7 @@ signals:
 public slots:
 
 private:
-    QtMobility::QGraphicsGeoMap *m_mapView;
-
-    QtMobility::QGeoServiceProvider *serviceProvider;
-    QtMobility::QGeoMappingManager *manager;
+    QtMobility::QGraphicsGeoMap *m_mapWidget;
 
     QGraphicsView *m_qgv;
     QGraphicsScene *m_scene;
